import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom
} from 'd3';
import { dropdownMenu } from './dropdownMenu';
import { scatterPlot } from './scatterPlot';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

let data;
let xColumn;
let yColumn;

const onXColumnClicked = column => {
  xColumn = column;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

const render = () => {
  
  select('#x-menu')
    .call(dropdownMenu, {
      options: data.columns,
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
    });
  
  //data.columns[1]//
  
  select('#y-menu')
    .call(dropdownMenu, {
      options: data.columns,
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });
  
  svg.call(scatterPlot, {
    xValue: d => d[xColumn],
    xAxisLabel: 'PM2.5 Micrograms Per Cubic Meter',
    yValue: d => d[yColumn],
    circleRadius: 5,
    yAxisLabel: yColumn,
    margin: { top: 40, right: 60, bottom: 88, left: 160 },
    width,
    height,
    data
  });
};


csv('data.csv')
  .then(loadedData => {
    data = loadedData;
    data.forEach(d => {
			d.LosAngeles = +d.LosAngeles;
   		d.LA_Median_Household_Income = +d.LA_Median_Household_Income;
    	d.LA_Median_Family_Income = +d.LA_Median_Family_Income;
      d.LA_Percentage_Without_Health_Insurance = +d.LA_Percentage_Without_Health_Insurance;
      d.LA_Percentage_Below_Poverty_Line = +d.LA_Percentage_Below_Poverty_Line;
			d.OrangeCounty = +d.OrangeCounty;
   		d.OC_MedianHousehold_Income = +d.OC_MedianHousehold_Income;
    	d.OC_Median_Family_Income = +d.OC_Median_Family_Income;
    	d.OC_Percentage_Without_HealthInsurance = +d.OC_Percentage_Without_HealthInsurance;
      d.OC_Percentage_Below_Poverty_Line = +d.OC_Percentage_Below_Poverty_Line;
			d.SanFranciscoBayArea = +d.SanFranciscoBayArea;
   		d.SF_Median_Household_Income = +d.SF_Median_Household_Income;
    	d.SF_Median_Family_Income = +d.SF_Median_Family_Income;
    	d.SF_Percentage_Without_HealthCare = +d.SF_Percentage_Without_HealthCare;
      d.SF_Percentage_Below_Poverty_Line = +d.SF_Percentage_Below_Poverty_Line;
    });
    xColumn = data.columns[0];
    yColumn = data.columns[1];
    render();
  });